@@ -1,7 +1,7 @@
 /*
     GNOME Commander - A GNOME based file manager
     Copyright (C) 2001-2006 Marcus Bjurman
-    Copyright (C) 2007-2009 Piotr Eljasiak
+    Copyright (C) 2007-2010 Piotr Eljasiak
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -21,8 +21,6 @@
 #ifndef __GNOME_CMD_FILE_INFO_H__
 #define __GNOME_CMD_FILE_INFO_H__
 
-G_BEGIN_DECLS
-
 #define GNOME_CMD_FILE_INFO(obj)          GTK_CHECK_CAST (obj, gnome_cmd_file_info_get_type (), GnomeCmdFileInfo)
 #define GNOME_CMD_FILE_INFO_CLASS(klass)  GTK_CHECK_CLASS_CAST (klass, gnome_cmd_file_info_get_type (), GnomeCmdFileInfoClass)
 #define GNOME_CMD_IS_FILE_INFO(obj)       GTK_CHECK_TYPE (obj, gnome_cmd_file_info_get_type ())
@@ -30,7 +28,6 @@ G_BEGIN_DECLS
 
 typedef struct _GnomeCmdFileInfo        GnomeCmdFileInfo;
 typedef struct _GnomeCmdFileInfoClass   GnomeCmdFileInfoClass;
-typedef struct _GnomeCmdFileInfoPrivate GnomeCmdFileInfoPrivate;
 
 struct _GnomeCmdFileInfo
 {
@@ -38,8 +35,6 @@ struct _GnomeCmdFileInfo
 
     GnomeVFSURI *uri;
     GnomeVFSFileInfo *info;
-
-    GnomeCmdFileInfoPrivate *priv;
 };
 
 struct _GnomeCmdFileInfoClass
@@ -52,6 +47,4 @@ GtkType gnome_cmd_file_info_get_type ();
 
 void gnome_cmd_file_info_setup (GnomeCmdFileInfo *f, GnomeVFSURI *uri, GnomeVFSFileInfo *info);
 
-G_END_DECLS
-
 #endif //__GNOME_CMD_FILE_INFO_H__
