@@ -335,7 +335,7 @@ static gboolean on_dialog_keypress (GnomeCmdBookmarkDialog *dialog, GdkEventKey
 
 
 static void on_dir_selected (GtkCList *list, gint row, gint column,
-                              GdkEventButton *event, GnomeCmdBookmarkDialog *dialog)
+                             GdkEventButton *event, GnomeCmdBookmarkDialog *dialog)
 {
     if (event && event->type == GDK_2BUTTON_PRESS)
         on_dir_goto (NULL, dialog);
@@ -345,9 +345,8 @@ static void on_dir_selected (GtkCList *list, gint row, gint column,
         gtk_widget_set_sensitive (dialog->priv->remove_btn, TRUE);
         gtk_widget_set_sensitive (dialog->priv->edit_btn, TRUE);
         gtk_widget_set_sensitive (dialog->priv->goto_btn, TRUE);
+        update_move_buttons (dialog, row);
     }
-
-    update_move_buttons (dialog, row);
 }
 
 
@@ -400,7 +399,7 @@ static void add_bookmarks (GnomeCmdBookmarkDialog *dialog)
         GnomeCmdCon *con = (GnomeCmdCon *) all_cons->data;
         group = gnome_cmd_con_get_bookmarks (con);
 
-        if (group->bookmarks)
+        if (group && group->bookmarks)
         {
             group->data = (gpointer *) dialog;
             dialog->priv->groups = g_list_append (dialog->priv->groups, group);
