@@ -1,6 +1,7 @@
 /*
     GNOME Commander - A GNOME based file manager
     Copyright (C) 2001-2006 Marcus Bjurman
+    Copyright (C) 2007-2010 Piotr Eljasiak
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -28,29 +29,24 @@
     GTK_CHECK_TYPE (obj, gnome_cmd_chown_dialog_get_type ())
 
 
-typedef struct _GnomeCmdChownDialog GnomeCmdChownDialog;
-typedef struct _GnomeCmdChownDialogPrivate GnomeCmdChownDialogPrivate;
-typedef struct _GnomeCmdChownDialogClass GnomeCmdChownDialogClass;
+struct GnomeCmdChownDialogPrivate;
 
 
-
-struct _GnomeCmdChownDialog
+struct GnomeCmdChownDialog
 {
     GnomeCmdDialog parent;
     GnomeCmdChownDialogPrivate *priv;
 };
 
 
-struct _GnomeCmdChownDialogClass
+struct GnomeCmdChownDialogClass
 {
     GnomeCmdDialogClass parent_class;
 };
 
 
-GtkWidget*
-gnome_cmd_chown_dialog_new (GList *files);
+GtkWidget *gnome_cmd_chown_dialog_new (GList *files);
 
-GtkType
-gnome_cmd_chown_dialog_get_type (void);
+GtkType gnome_cmd_chown_dialog_get_type ();
 
 #endif // __GNOME_CMD_CHOWN_DIALOG_H__
