@@ -1,6 +1,7 @@
 /*
     GNOME Commander - A GNOME based file manager
     Copyright (C) 2001-2006 Marcus Bjurman
+    Copyright (C) 2007-2010 Piotr Eljasiak
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -27,27 +28,25 @@
     GTK_CHECK_TYPE (obj, gnome_cmd_cmdline_get_type ())
 
 
-typedef struct _GnomeCmdCmdline GnomeCmdCmdline;
-typedef struct _GnomeCmdCmdlinePrivate GnomeCmdCmdlinePrivate;
-typedef struct _GnomeCmdCmdlineClass GnomeCmdCmdlineClass;
+struct GnomeCmdCmdlinePrivate;
 
 
-struct _GnomeCmdCmdline
+struct GnomeCmdCmdline
 {
     GtkHBox parent;
     GnomeCmdCmdlinePrivate *priv;
 };
 
 
-struct _GnomeCmdCmdlineClass
+struct GnomeCmdCmdlineClass
 {
     GtkHBoxClass parent_class;
 };
 
 
-GtkWidget *gnome_cmd_cmdline_new (void);
+GtkWidget *gnome_cmd_cmdline_new ();
 
-GtkType gnome_cmd_cmdline_get_type (void);
+GtkType gnome_cmd_cmdline_get_type ();
 
 GtkWidget *gnome_cmd_cmdline_get_entry (GnomeCmdCmdline *cmdline);
 
