@@ -116,11 +116,15 @@ static void class_init (GnomeCmdFileClass *klass)
 
 static void init (GnomeCmdFile *file)
 {
-    file->info = NULL;
-    file->collate_key = NULL;
+    // file->info = NULL;
+    // file->collate_key = NULL;
 
     file->priv = g_new0 (GnomeCmdFilePrivate, 1);
-    file->priv->dir_handle = NULL;
+
+    // file->priv->dir_handle = NULL;
+
+    // file->priv->last_update.tv_sec = 0;
+    // file->priv->last_update.tv_usec = 0;
 
     file->priv->tree_size = -1;
 
@@ -129,10 +133,6 @@ static void init (GnomeCmdFile *file)
         all_files = g_list_append (all_files, file);
         created_files_cnt++;
     }
-
-    file->priv->last_update.tv_sec = 0;
-    file->priv->last_update.tv_usec = 0;
-
 }
 
 
@@ -409,7 +409,7 @@ gchar *gnome_cmd_file_get_real_path (GnomeCmdFile *f)
 gchar *gnome_cmd_file_get_quoted_real_path (GnomeCmdFile *f)
 {
     gchar *path = gnome_cmd_file_get_real_path (f);
-    gchar *ret = path ? quote_if_needed (path) : NULL;
+    gchar *ret = quote_if_needed (path);
 
     g_free (path);
 
@@ -755,7 +755,7 @@ inline void do_view_file (GnomeCmdFile *f, gint internal_viewer=-1)
         case FALSE: {
                         gchar *filename = gnome_cmd_file_get_quoted_real_path (f);
                         gchar *command = g_strdup_printf (gnome_cmd_data.get_viewer(), filename);
-                        run_command (command, FALSE);
+                        run_command (command);
                         g_free (filename);
                     }
                     break;
