@@ -24,7 +24,7 @@
 
 #include "gnome-cmd-includes.h"
 #include "gnome-cmd-bookmark-dialog.h"
-#include "gnome-cmd-con.h"
+#include "gnome-cmd-con-home.h"
 #include "gnome-cmd-con-list.h"
 #include "gnome-cmd-data.h"
 #include "gnome-cmd-dir.h"
@@ -665,7 +665,7 @@ void file_edit (GtkMenuItem *menuitem, gpointer not_used)
     gdk_window_get_pointer (NULL, NULL, NULL, &mask);
 
     if (mask & GDK_SHIFT_MASK)
-        gnome_cmd_file_selector_start_editor (get_fs (ACTIVE));
+        gnome_cmd_file_selector_show_new_textfile_dialog (get_fs (ACTIVE));
     else
         gnome_cmd_file_list_edit (get_fl (ACTIVE));
 }
@@ -673,7 +673,7 @@ void file_edit (GtkMenuItem *menuitem, gpointer not_used)
 
 void file_edit_new_doc (GtkMenuItem *menuitem, gpointer not_used)
 {
-    gnome_cmd_file_selector_start_editor (get_fs (ACTIVE));
+    gnome_cmd_file_selector_show_new_textfile_dialog (get_fs (ACTIVE));
 }
 
 
@@ -821,8 +821,7 @@ void file_diff (GtkMenuItem *menuitem, gpointer not_used)
     {
         gchar *cmd = g_strdup_printf (gnome_cmd_data.get_differ(), s.c_str(), "");
 
-        g_print (_("running `%s'\n"), cmd);
-        run_command (cmd, FALSE);
+        run_command (cmd);
 
         g_free (cmd);
     }
@@ -847,8 +846,7 @@ void file_sync_dirs (GtkMenuItem *menuitem, gpointer not_used)
 
     gchar *cmd = g_strdup_printf (gnome_cmd_data.get_differ(), s.c_str(), "");
 
-    g_print (_("running `%s'\n"), cmd);
-    run_command (cmd, FALSE);
+    run_command (cmd);
 
     g_free (cmd);
 }
@@ -1108,25 +1106,37 @@ void command_open_nautilus_in_cwd (GtkMenuItem *menuitem, gpointer not_used)
 
 void command_root_mode (GtkMenuItem *menuitem, gpointer not_used)
 {
-    char *su;
+    char *su = NULL;
+    gboolean need_c = FALSE;
 
-    su = g_find_program_in_path ("gksu");
-    if  (!su)
-        su = g_find_program_in_path ("kdesu");
-    if  (!su)
-        su = g_find_program_in_path ("beesu");
+    if ((su = g_find_program_in_path ("xdg-su")))
+        goto with_c_param;
+    if ((su = g_find_program_in_path ("gksu")))
+        goto without_c_param;
+    if ((su = g_find_program_in_path ("gnomesu")))
+        goto with_c_param;
+    if ((su = g_find_program_in_path ("beesu")))
+        goto without_c_param;
+    if ((su = g_find_program_in_path ("kdesu")))
+        goto without_c_param;
 
-    if  (!su)
-    {
-        gnome_cmd_show_message (NULL, _("gksu, kdesu or beesu is not found."));
-        return ;
-    }
+    gnome_cmd_show_message (NULL, _("xdg-su, gksu, gnomesu, kdesu or beesu is not found."));
+    return;
 
-    char *argv[3];
+  with_c_param:
 
-    argv[0] = su;
-    argv[1] = g_get_prgname ();
-    argv[2] = NULL;
+    need_c = TRUE;
+
+  without_c_param:
+
+    char *argv[4];
+    int i = 0;
+
+    argv[i++] = su;
+    argv[i++] = g_get_prgname ();
+    if (need_c)
+        argv[i++] = "-c";
+    argv[i++] = NULL;
 
     GError *error = NULL;
 
@@ -1432,7 +1442,8 @@ void connections_close_current (GtkMenuItem *menuitem, gpointer not_used)
 {
     GnomeCmdCon *con = get_fs (ACTIVE)->get_connection();
 
-    connections_close (menuitem, con);
+    if (!GNOME_CMD_IS_CON_HOME (con))
+        connections_close (menuitem, con);
 }
 
 
