@@ -5,6 +5,7 @@
     Part of
         GNOME Commander - A GNOME based file manager
         Copyright (C) 2001-2006 Marcus Bjurman
+        Copyright (C) 2007-2010 Piotr Eljasiak
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -22,17 +23,19 @@
 */
 
 #include <config.h>
-
 #include <libgnome/libgnome.h>
 
 #include "libgviewer.h"
 
+using namespace std;
+
+
 static GtkDialogClass *parent_class = NULL;
 
 static void search_progress_dlg_destroy (GtkObject *object);
 static void search_progress_dlg_action_response(GtkDialog *dlg, gint arg1, GViewerSearchProgressDlg *sdlg);
 
-struct _GViewerSearchProgressDlgPrivate
+struct GViewerSearchProgressDlgPrivate
 {
     GtkWidget *label, *progressbar;
     gdouble progress;
@@ -110,7 +113,7 @@ static void search_progress_dlg_destroy (GtkObject *object)
 }
 
 
-GType gviewer_search_progress_dlg_get_type (void)
+GType gviewer_search_progress_dlg_get_type ()
 {
     static GType ttt_type = 0;
     if (!ttt_type)
@@ -153,13 +156,13 @@ gboolean search_progress_dlg_timeout(gpointer data)
 
     GViewerSearchProgressDlg *w = GVIEWER_SEARCH_PROGRESS_DLG(data);
 
-    progress = g_atomic_int_get(w->priv->progress_value);
+    progress = g_atomic_int_get (w->priv->progress_value);
 
     g_snprintf(text, sizeof(text), "%3.1f%%", progress/10.0);
     gtk_progress_bar_set_text(GTK_PROGRESS_BAR(w->priv->progressbar), text);
     gtk_progress_bar_set_fraction(GTK_PROGRESS_BAR(w->priv->progressbar), progress/1000.0);
 
-    if (g_atomic_int_get(w->priv->completed_indicator)!=0)
+    if (g_atomic_int_get (w->priv->completed_indicator)!=0)
     {
         gtk_dialog_response(GTK_DIALOG(w), GTK_RESPONSE_CANCEL);
         return FALSE;
@@ -192,7 +195,7 @@ void gviewer_show_search_progress_dlg(GtkWindow *parent, const gchar *searching_
 
     gint timeout_source_id = g_timeout_add (300, search_progress_dlg_timeout, (gpointer) dlg);
 
-    dprogress = g_atomic_int_get(dlg->priv->progress_value);
+    dprogress = g_atomic_int_get (dlg->priv->progress_value);
     g_snprintf(text, sizeof(text), "%3.1f%%", dprogress/10.0);
     gtk_progress_bar_set_text(GTK_PROGRESS_BAR(dlg->priv->progressbar), text);
     gtk_progress_bar_set_fraction(GTK_PROGRESS_BAR(dlg->priv->progressbar), dprogress/1000.0);
